@@ -19,15 +19,15 @@ fn can_assign_break_using_second_place() {
                         latest: format_time(1000.).to_string(),
                         location: vec![30., 0.].to_loc(),
                     }),
-                    breaks: Some(vec![VehicleBreak {
-                        time: VehicleBreakTime::TimeWindow(vec![format_time(10.), format_time(30.)]),
+                    breaks: Some(vec![VehicleBreak::Optional {
+                        time: VehicleOptionalBreakTime::TimeWindow(vec![format_time(10.), format_time(30.)]),
                         places: vec![
-                            VehicleBreakPlace {
+                            VehicleOptionalBreakPlace {
                                 duration: 2.0,
                                 location: Some(vec![1., 0.].to_loc()),
                                 tag: Some("first".to_string()),
                             },
-                            VehicleBreakPlace {
+                            VehicleOptionalBreakPlace {
                                 duration: 2.0,
                                 location: Some(vec![11., 0.].to_loc()),
                                 tag: Some("second".to_string()),
