@@ -18,7 +18,7 @@ fn can_handle_limited_capacity() {
                     vec![((11., 0.), 1., vec![2])],
                 ),
             ],
-            relations: Option::None,
+            ..create_empty_plan()
         },
         fleet: Fleet {
             vehicles: vec![create_vehicle_with_capacity("my_vehicle", vec![2])],
@@ -36,7 +36,7 @@ fn can_handle_limited_capacity() {
             cost: 88.,
             distance: 36,
             duration: 42,
-            times: Timing { driving: 36, serving: 6, waiting: 0, break_time: 0 },
+            times: Timing { driving: 36, serving: 6, ..Timing::default() },
         }
     );
     assert!(solution.unassigned.is_none());
