@@ -39,8 +39,9 @@ fn check_vehicles_impl(known_ids: Vec<&str>, tours: Vec<(&str, usize)>, expected
             .collect(),
         ..create_empty_solution()
     };
+    let ctx = CheckerContext::new(create_example_problem(), problem, None, solution).unwrap();
 
-    let result = check_vehicles(&CheckerContext::new(create_example_problem(), problem, None, solution));
+    let result = check_vehicles(&ctx);
 
     assert_eq!(result.map_err(|_| ()), expected_result);
 }
@@ -152,7 +153,7 @@ fn check_jobs_impl(
                     ..create_job(id)
                 })
                 .collect(),
-            relations: None,
+            ..create_empty_plan()
         },
         fleet: Fleet { vehicles: vec![create_default_vehicle_type()], profiles: create_default_matrix_profiles() },
         ..create_empty_problem()
@@ -174,8 +175,9 @@ fn check_jobs_impl(
         ),
         ..create_empty_solution()
     };
+    let ctx = CheckerContext::new(create_example_problem(), problem, None, solution).unwrap();
 
-    let result = check_jobs_presence(&CheckerContext::new(create_example_problem(), problem, None, solution));
+    let result = check_jobs_presence(&ctx);
 
     assert_eq!(result, expected_result);
 }
@@ -185,7 +187,7 @@ fn can_detect_time_window_violation() {
     let problem = Problem {
         plan: Plan {
             jobs: vec![create_delivery_job_with_times("job1", vec![1., 0.], vec![(1, 2)], 1.)],
-            relations: None,
+            ..create_empty_plan()
         },
         fleet: Fleet { vehicles: vec![create_default_vehicle_type()], profiles: create_default_matrix_profiles() },
         ..create_empty_problem()
@@ -195,7 +197,7 @@ fn can_detect_time_window_violation() {
             cost: 15.,
             distance: 2,
             duration: 3,
-            times: Timing { driving: 2, serving: 1, waiting: 0, break_time: 0 },
+            times: Timing { driving: 2, serving: 1, ..Timing::default() },
         },
         tours: vec![Tour {
             vehicle_id: "my_vehicle_1".to_string(),
@@ -231,14 +233,15 @@ fn can_detect_time_window_violation() {
                 cost: 15.,
                 distance: 2,
                 duration: 3,
-                times: Timing { driving: 2, serving: 1, waiting: 0, break_time: 0 },
+                times: Timing { driving: 2, serving: 1, ..Timing::default() },
             },
         }],
         ..create_empty_solution()
     };
     let core_problem = Arc::new(problem.clone().read_pragmatic().unwrap());
+    let ctx = CheckerContext::new(core_problem, problem, None, solution).unwrap();
 
-    let result = check_assignment(&CheckerContext::new(core_problem, problem, None, solution));
+    let result = check_assignment(&ctx);
 
     assert_eq!(result, Err(vec!["cannot match activities to jobs: job1:<no tag>".to_owned()]));
 }
@@ -248,7 +251,7 @@ fn can_detect_job_duration_violation() {
     let problem = Problem {
         plan: Plan {
             jobs: vec![create_delivery_job_with_times("job1", vec![1., 0.], vec![(5, 10)], 1.)],
-            relations: None,
+            ..create_empty_plan()
         },
         fleet: Fleet { vehicles: vec![create_default_vehicle_type()], profiles: create_default_matrix_profiles() },
         ..create_empty_problem()
@@ -258,7 +261,7 @@ fn can_detect_job_duration_violation() {
             cost: 18.,
             distance: 2,
             duration: 6,
-            times: Timing { driving: 2, serving: 2, waiting: 2, break_time: 0 },
+            times: Timing { driving: 2, serving: 2, waiting: 2, ..Timing::default() },
         },
         tours: vec![Tour {
             vehicle_id: "my_vehicle_1".to_string(),
@@ -294,14 +297,15 @@ fn can_detect_job_duration_violation() {
                 cost: 18.,
                 distance: 2,
                 duration: 6,
-                times: Timing { driving: 2, serving: 2, waiting: 2, break_time: 0 },
+                times: Timing { driving: 2, serving: 2, waiting: 2, ..Timing::default() },
             },
         }],
         ..create_empty_solution()
     };
     let core_problem = Arc::new(problem.clone().read_pragmatic().unwrap());
+    let ctx = CheckerContext::new(core_problem, problem, None, solution).unwrap();
 
-    let result = check_assignment(&CheckerContext::new(core_problem, problem, None, solution));
+    let result = check_assignment(&ctx);
 
     assert_eq!(result, Err(vec!["cannot match activities to jobs: job1:<no tag>".to_owned()]));
 }
@@ -309,7 +313,7 @@ fn can_detect_job_duration_violation() {
 #[test]
 fn can_detect_dispatch_violations() {
     let problem = Problem {
-        plan: Plan { jobs: vec![create_delivery_job("job1", vec![2., 0.])], relations: None },
+        plan: Plan { jobs: vec![create_delivery_job("job1", vec![2., 0.])], ..create_empty_plan() },
         fleet: Fleet {
             vehicles: vec![VehicleType {
                 shifts: vec![VehicleShift {
@@ -361,8 +365,9 @@ fn can_detect_dispatch_violations() {
         ..create_empty_solution()
     };
     let core_problem = Arc::new(problem.clone().read_pragmatic().unwrap());
+    let ctx = CheckerContext::new(core_problem, problem, None, solution).unwrap();
 
-    let result = check_dispatch(&CheckerContext::new(core_problem, problem, None, solution));
+    let result = check_dispatch(&ctx);
 
     assert_eq!(result, Err("tour should have dispatch, but none is found: 'my_vehicle_1'".to_owned()));
 }
@@ -375,7 +380,7 @@ fn can_detect_group_violations() {
                 create_delivery_job_with_group("job1", vec![1., 0.], "group1"),
                 create_delivery_job_with_group("job2", vec![1., 0.], "group1"),
             ],
-            relations: None,
+            ..create_empty_plan()
         },
         fleet: Fleet {
             vehicles: vec![VehicleType {
@@ -420,8 +425,9 @@ fn can_detect_group_violations() {
     let solution =
         Solution { tours: vec![create_tour("v1", "job1"), create_tour("v2", "job2")], ..create_empty_solution() };
     let core_problem = Arc::new(problem.clone().read_pragmatic().unwrap());
+    let ctx = CheckerContext::new(core_problem, problem, None, solution).unwrap();
 
-    let result = check_groups(&CheckerContext::new(core_problem, problem, None, solution));
+    let result = check_groups(&ctx);
 
     assert_eq!(result, Err("job groups are not respected: 'group1'".to_owned()));
 }
